@@ -517,7 +517,7 @@ for (i=0;i<ns;i++) {
 				if (nmiss>0) {
 					for (k=0;k<JY;k++) {
 						for (t=0;t<JY;t++) {
-							if (ISNAN(REAL(Yimp)[j+k*IY])&ISNAN(REAL(Yimp)[j+t*IY])) {
+							if (ISNAN(REAL(Yimp)[j+k*IY])&&ISNAN(REAL(Yimp)[j+t*IY])) {
 								omegamm[countmm]=REAL(omega)[k+t*Io];
 								countmm++;
 							}
@@ -525,7 +525,7 @@ for (i=0;i<ns;i++) {
 								omegamo[countmo]=REAL(omega)[k+t*Io];
 								countmo++;	
 							}
-							else if (!ISNAN(REAL(Yimp)[j+k*IY])&!ISNAN(REAL(Yimp)[j+t*IY])){
+							else if (!ISNAN(REAL(Yimp)[j+k*IY])&&!ISNAN(REAL(Yimp)[j+t*IY])){
 								omegaoo[countoo]=REAL(omega)[k+t*Io];
 								countoo++;	
 							}
@@ -538,7 +538,6 @@ for (i=0;i<ns;i++) {
 					r8mat_poinv((JY-nmiss),help7,invomega4);
 					for (jj=1;jj<JY-nmiss;jj++) for (tt=0;tt<jj;tt++) invomega4[jj+(JY-nmiss)*tt]=invomega4[tt+(JY-nmiss)*jj];
 					r8mat_mmt_new((JY-nmiss),(JY-nmiss),nmiss,invomega4,omegamo,help8);
-					r8mat_add(1,nmiss,betamiss,mumiss);
 					r8mat_mm_new(nmiss,(JY-nmiss),nmiss,omegamo,help8,omegadrawmiss);
 					r8mat_divide(nmiss,nmiss,-1,omegadrawmiss);
 					r8mat_add(nmiss,nmiss,omegamm,omegadrawmiss);
@@ -612,6 +611,7 @@ for (i=0;i<ns;i++) {
 	
 	}
 	if ((i+1)%fl==0) Rprintf(".");
+	if ((i+1)%(fl*50)==0) Rprintf("\n");
 }
 if (fl==1) Rprintf("\n");
 for(i=0;i<IY;i++)  {
